@@ -166,67 +166,4 @@ getDictionary <- function(x, dsnm) {
 }
 
 
-getDictionary_back <- function(x, dsnm) {
-  
-  ret <- NULL
-  rw <- NULL
-  usr_wdth <- c()
-  str_wdth <- c()
-  cntr <- 0
-  
-  for (nm in names(x)) {
-    
-    
-    
-    cntr <- cntr + 1
-    
-    lbl <- attr(x[[nm]], "label")
-    desc <- attr(x[[nm]], "description")
-    fmt <- paste(as.character(attr(x[[nm]], "format")), collapse = "\n")
-    jst <- attr(x[[nm]], "justify")
-    wdth <- attr(x[[nm]], "width")
-    
-    if (fmt == "")
-      fmt <- NA
-    
-    if (is.null(wdth)) {
-      if (length(x[[nm]]) > 0) {
-        str_wdth[cntr] <- ifelse(typeof(x[[nm]]) == "character", 
-                                 max(nchar(x[[nm]])),
-                                 NA) 
-      } else {
-        
-        str_wdth[cntr] <- NA
-      }
-      
-    } else {
-      usr_wdth[cntr] <- wdth 
-    }
-    
-    rw <- data.frame(Name = dsnm,
-                     Column = nm,
-                     Class = paste0(class(x[[nm]]), collapse = " "),
-                     Label = ifelse(!is.null(lbl), lbl, as.character(NA)),
-                     Description = ifelse(!is.null(desc), desc, as.character(NA)),
-                     Format = ifelse(!is.null(fmt), fmt, NA),
-                     Width = ifelse(!is.null(wdth), wdth, NA),
-                     Justify = ifelse(!is.null(jst), jst, as.character(NA)),
-                     Rows = nrow(x),
-                     NAs = sum(is.na(x[[nm]])))
-    
-    
-    if (is.null(ret))
-      ret <- rw
-    else 
-      ret <- rbind(ret, rw)
-    
-  }
-  
-  
-  if (length(usr_wdth) == 0)
-    ret[["Width"]] <- str_wdth
-  
-  return(ret)
-  
-}
 
